/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.container.host;

/**
 * An object that returns {@link SystemMemoryStatistics} for the {@link org.apache.samza.container.SamzaContainer}.
 */
public interface SystemStatisticsGetter {

  /**
   * Returns the {@link SystemMemoryStatistics} for the current Samza container process. A 'null' value is
   * returned if no statistics are available.
   *
   * @return {@link SystemMemoryStatistics} for the Samza container
   */
  SystemMemoryStatistics getSystemMemoryStatistics();

  /**
   * Returns the {@link ProcessCPUStatistics} for the current Samza container process(includes its child processes). A
   * 'null' value is returned if no statistics are available.
   *
   * @return {@link ProcessCPUStatistics} for the Samza container process
   */
  ProcessCPUStatistics getProcessCPUStatistics();
}
